simulations

package
v0.0.0-...-f8ecacf Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2016 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Odds

func Odds(c *Agent, f *Agent) int

func SimAttack

func SimAttack(a *Agent, d *Agent) (*Agent, *Agent)

func SimFight

func SimFight(c Agent, f Agent) bool

SimFight simulates combat between character and a proposed foe. Outcome predition is output as a percentage chance for the character to win. Experience point rewards should be based on this metric where fights with long odds give greater experience.

Types

This section is empty.

Jump to