Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SimFight ¶
func SimFight(c Agent, f Agent) bool
SimFight simulates combat between character and a proposed foe. Outcome predition is output as a percentage chance for the character to win. Experience point rewards should be based on this metric where fights with long odds give greater experience.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.